@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
 	my ($class) = @_;
@@ -1131,9 +1131,7 @@ sub parse {
     my ($class, $program) = @_;
     if($program =~ $parser) {
         my $code = $/{Lang}->X();
-		#print $code;
         eval $code;
-        #writeFile("/home/pc/Documents/work/hex/generatedCode.pl", $code);
     } else {
         print "Not matched";
     }
@@ -1145,41 +1143,19 @@ __END__
 
 =head1 NAME
 
-Lang::HEX - Perl extension for blah blah blah
+Lang::HEX
 
 =head1 SYNOPSIS
 
-  use Lang::HEX;
-  blah blah blah
+  $> hex <directoryName>
 
 =head1 DESCRIPTION
 
-Stub documentation for Lang::HEX, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head2 EXPORT
-
-None by default.
-
-
-
-=head1 SEE ALSO
-
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+Hex is a programming language, for more documentation please visit http://.....
 
 =head1 AUTHOR
 
-pc, E<lt>pc@E<gt>
+Rajkumar Reddy
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -1189,5 +1165,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.30.0 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
